ConvKB
======

.. currentmodule:: pykeen.models

.. autoclass:: ConvKB
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ConvKB.hpo_default
      ~ConvKB.regularizer_default_kwargs

   .. rubric:: Methods Summary

   .. autosummary::

      ~ConvKB.score_hrt

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
   .. autoattribute:: regularizer_default_kwargs

   .. rubric:: Methods Documentation

   .. automethod:: score_hrt
